@@ -1,7 +1,7 @@
 from adaptive_scheduler import client_support, scheduler, server_support, utils
 from adaptive_scheduler._version import __version__
 from adaptive_scheduler.scheduler import PBS, SLURM
-from adaptive_scheduler.server_support import RunManager
+from adaptive_scheduler.server_support import RunManager, slurm_run
 
 __all__ = [
     "client_support",
@@ -11,5 +11,6 @@ __all__ = [
     "server_support",
     "SLURM",
     "utils",
+    "slurm_run",
     "__version__",
 ]
